@@ -42,25 +42,25 @@ class Serialize(object):
         
         address = ET.SubElement(parent, tag)
         
-        if schema.firstname:
+        if schema.firstname is not None:
             ET.SubElement(address, 'firstName').text = schema.firstname
-        if schema.lastname:
+        if schema.lastname is not None:
             ET.SubElement(address, 'lastName').text  = schema.lastname
-        if schema.company:
+        if schema.company is not None:
             ET.SubElement(address, 'company').text   = schema.company
-        if schema.address:
+        if schema.address is not None:
             ET.SubElement(address, 'address').text   = schema.address
-        if schema.city:
+        if schema.city is not None:
             ET.SubElement(address, 'city').text      = schema.city
-        if schema.state:
+        if schema.state is not None:
             ET.SubElement(address, 'state').text     = schema.state
-        if schema.postal_code:
+        if schema.postal_code is not None:
             ET.SubElement(address, 'zip').text       = schema.postal_code
-        if schema.country:
+        if schema.country is not None:
             ET.SubElement(address, 'country').text   = schema.country
-        if schema.phone:
+        if schema.phone is not None:
             ET.SubElement(address, 'phoneNumber').text = schema.phone
-        if schema.fax:
+        if schema.fax is not None:
             ET.SubElement(address, 'faxNumber').text   = schema.fax
         
         return address
@@ -72,11 +72,11 @@ class Serialize(object):
         tranny   = transaction.transaction
         
         # Build out rest of transaction body
-        if tranny.amount:
+        if tranny.amount is not None:
             ET.SubElement(transact, 'amount').text = tranny.amount
         
         # Taxes! Yay!
-        if tranny.tax:
+        if tranny.tax is not None:
             tax = ET.SubElement(transact, 'tax')
             
             ET.SubElement(tax, 'amount').text      = tranny.tax.amount
@@ -84,7 +84,7 @@ class Serialize(object):
             ET.SubElement(tax, 'description').text = tranny.tax.description
         
         # Shipping...Freight...Authorize.net can't make up their minds!
-        if tranny.freight:
+        if tranny.freight is not None:
             # Note, we use "freight" but authorize.net wants it "shipping"
             freight = ET.SubElement(transact, 'shipping')
             
@@ -93,7 +93,7 @@ class Serialize(object):
             ET.SubElement(freight, 'description').text = tranny.freight.description
         
         # Duty...don't buy it at the airport!
-        if tranny.duty:
+        if tranny.duty is not None:
             duty = ET.SubElement(transact, 'duty')
             
             ET.SubElement(duty, 'amount').text      = tranny.duty.amount
@@ -101,7 +101,7 @@ class Serialize(object):
             ET.SubElement(duty, 'description').text = tranny.duty.description
         
         # We can have multiple line items...
-        if tranny.line_item:
+        if tranny.line_item is not None:
             for line_item in tranny.line_item:
                 oh_yes = ET.SubElement(transact, 'lineItems')
                 
@@ -114,83 +114,83 @@ class Serialize(object):
         
         
         # Profile ID's and transaction ID's
-        if transaction.id:
+        if transaction.id is not None:
             ET.SubElement(transact, 'customerProfileId').text = str(transaction.id)
-        if transaction.billing_id:
+        if transaction.billing_id is not None:
             ET.SubElement(transact, 'customerPaymentProfileId').text = str(transaction.billing_id)
-        if transaction.shipping_id:
+        if transaction.shipping_id is not None:
             ET.SubElement(transact, 'customerShippingAddressId').text = str(transaction.shipping_id)
-        if tranny.transaction_id:
+        if tranny.transaction_id is not None:
             ET.SubElement(transact, 'transId').text = tranny.transaction_id
         
         # If we have any data on the user
         order = False
         
-        if tranny.invoice:
+        if tranny.invoice is not None:
             order = ET.SubElement(transact, 'order')
             ET.SubElement(order, 'invoiceNumber').text = tranny.invoice
-        if tranny.description:
+        if tranny.description is not None:
             if not order:
                 order = ET.SubElement(transact, 'order')
             ET.SubElement(order, 'description').text = tranny.description
-        if tranny.po:
+        if tranny.po is not None:
             if not order:
                 order = ET.SubElement(transact, 'order')
             ET.SubElement(order, 'purchaseOrderNumber').text = tranny.po
         
         # Tax exemption and miscellany
-        if tranny.tax_exempt:
+        if tranny.tax_exempt is not None:
             ET.SubElement(transact, 'taxExempt').text = tranny.tax_exempt
-        if tranny.recurring_billing:
+        if tranny.recurring_billing is not None:
             ET.SubElement(transact, 'recurringBilling').text = str(tranny.recurring_billing).upper()
-        if tranny.split_tender_id:
+        if tranny.split_tender_id is not None:
             ET.SubElement(transact, 'splitTenderId').text = tranny.split_tender_id
-        if tranny.ccv:
+        if tranny.ccv is not None:
             ET.SubElement(transact, 'cardCode').text = tranny.ccv
         
         # Extra options...
         extra_options = []
         
-        if tranny.version:
+        if tranny.version is not None:
             extra_options.append('x_version=%s' % tranny.version)
-        if tranny.delim_char:
+        if tranny.delim_char is not None:
             extra_options.append('x_delim_char=%s' % tranny.delim_char)
-        if tranny.delim_data:
+        if tranny.delim_data is not None:
             extra_options.append('x_delim_data=%s' % tranny.delim_data)
-        if tranny.relay_response:
+        if tranny.relay_response is not None:
             extra_options.append('x_relay_response=%s' % tranny.relay_response)
-        if tranny.customer_id:
+        if tranny.customer_id is not None:
             extra_options.append('x_cust_id=%s' % tranny.customer_id)
-        if tranny.customer_ip:
+        if tranny.customer_ip is not None:
             extra_options.append('x_customer_ip=%s' % tranny.customer_ip)
-        if tranny.customer_email:
+        if tranny.customer_email is not None:
             extra_options.append('x_email_customer=%s' % tranny.customer_email)
-        if tranny.email:
+        if tranny.email is not None:
             extra_options.append('x_email=%s' % tranny.email)
-        if tranny.description:
+        if tranny.description is not None:
             extra_options.append('x_description=%s' % tranny.description)
-        if tranny.merchant_email:
+        if tranny.merchant_email is not None:
             extra_options.append('x_merchant_email=%s' % tranny.merchant_email)
-        if tranny.allow_partial_auth:
+        if tranny.allow_partial_auth is not None:
             extra_options.append('x_allow_partial_auth=%s' % tranny.allow_partial_auth)
-        if tranny.auth_code:
+        if tranny.auth_code is not None:
             extra_options.append('x_auth_code=%s' % tranny.auth_code)
-        if tranny.authentication_indicator:
+        if tranny.authentication_indicator is not None:
             extra_options.append('x_authentication_indicator=%s' % tranny.authentication_indicator)
-        if tranny.cardholder_authentication_value:
+        if tranny.cardholder_authentication_value is not None:
             extra_options.append('x_cardholder_authentication_value=%s' % tranny.cardholder_authentication_value)
-        if tranny.duplicate_window:
+        if tranny.duplicate_window is not None:
             extra_options.append('x_duplicate_window=%s' % tranny.duplicate_window)
-        if tranny.encap_char:
+        if tranny.encap_char is not None:
             extra_options.append('x_encap_char=%s' % tranny.encap_char)
-        if tranny.footer_email_receipt:
+        if tranny.footer_email_receipt is not None:
             extra_options.append('x_footer_email_receipt=%s' % tranny.footer_email_receipt)
-        if tranny.header_email_receipt:
+        if tranny.header_email_receipt is not None:
             extra_options.appen('x_header_email_receipt=%s' % tranny.header_email_receipt)
-        if tranny.url:
+        if tranny.url is not None:
             extra_options.append('x_url=%s' % tranny.url)
         
-        if extra_options:
+        if extra_options is not None:
             extra      = ET.SubElement(root, 'extraOptions')
             extra.text = ET.CDATA('&'.join(extra_options))
     
@@ -244,7 +244,7 @@ class Serialize(object):
         ET.SubElement(authentication, 'transactionKey').text = auth.key
         
         # Set the reference ID
-        if hasattr(trans, 'ref_id') and trans.ref_id:
+        if hasattr(trans, 'ref_id') and (trans.ref_id is not None):
             ET.SubElement(root, 'refId').text = trans.ref_id
         
         # Now we start having fun - this shit is messay!
@@ -254,27 +254,27 @@ class Serialize(object):
                 # Create a brand new customer profile
                 profile  = ET.SubElement(root, 'profile')
                 
-                if trans.customer_id:
+                if trans.customer_id is not None:
                     ET.SubElement(profile, 'merchantCustomerId').text = trans.customer_id
-                if trans.description:
+                if trans.description is not None:
                     ET.SubElement(profile, 'description').text = trans.description
-                if trans.email:
+                if trans.email is not None:
                     ET.SubElement(profile, 'email').text = trans.email
                 
                 # Do we have a billing object schema?
-                if trans.billing:
+                if trans.billing is not None:
                     billing_list = trans.billing
                     
                     # We can have multiple ones...
                     for billing in billing_list:
                         billing_profile = ET.SubElement(profile, 'paymentProfiles')
-                        if billing.entity_type:
+                        if billing.entity_type is not None:
                             ET.SubElement(billing_profile, 'customerType').text = billing.entity_type
                         # Since a default is specified in the schema, entity type will exist
                         if len(billing.__dict__) > 1:
                             self._prototype_address(billing_profile, billing, 'billTo')
                          
-                        if billing.payment:
+                        if billing.payment is not None:
                             payment_profile = ET.SubElement(billing_profile, 'payment')
                             payment = billing.payment
                             
@@ -283,30 +283,30 @@ class Serialize(object):
                                 creditcard = ET.SubElement(payment_profile, 'creditCard')
                                 ET.SubElement(creditcard, 'cardNumber').text     = payment.number
                                 ET.SubElement(creditcard, 'expirationDate').text = payment.expiration.strftime('%Y-%m')
-                                if payment.ccv:
+                                if payment.ccv is not None:
                                     ET.SubElement(creditcard, 'cardCode').text   = payment.ccv
                             elif IBank.providedBy(payment):
                                 # Bank account payment type
                                 bank = ET.SubElement(payment_profile, 'bankAccount')
                                 
-                                if payment.account_type:
+                                if payment.account_type is not None:
                                     ET.SubElement(bank, 'accountType').text = payment.account_type
                                 
                                 ET.SubElement(bank, 'routingNumber').text = payment.routing_number
                                 ET.SubElement(bank, 'accountNumber').text = payment.account_number
                                 ET.SubElement(bank, 'nameOnAccount').text = payment.name_on_account
                                 
-                                if payment.echeck_type:
+                                if payment.echeck_type is not None:
                                     ET.SubElement(bank, 'echeckType').text = payment.echeck_type
-                                if payment.name:
+                                if payment.name is not None:
                                     ET.SubElement(bank, 'bankName').text = payment.name
                             else:
                                 raise CIMException('%s is not a supported payment type' % payment.__name__)
                 
-                if trans.validation:
+                if trans.validation is not None:
                     ET.SubElement(root, 'validationMode').text = trans.validation
                     
-                if trans.shipping:
+                if trans.shipping is not None:
                     shipping_list = trans.shipping
                     
                     # We can have multiple ones...
@@ -321,7 +321,7 @@ class Serialize(object):
                 
                 ET.SubElement(payment_profile, 'customerType').text = trans.billing.entity_type
                 
-                if trans.billing:
+                if trans.billing is not None:
                     self._prototype_address(payment_profile, trans.billing, 'billTo')
                 payment = trans.payment
                 
@@ -331,22 +331,22 @@ class Serialize(object):
                     creditcard = ET.SubElement(pymnt, 'creditCard')
                     ET.SubElement(creditcard, 'cardNumber').text     = payment.number
                     ET.SubElement(creditcard, 'expirationDate').text = payment.expiration.strftime('%Y-%m')
-                    if payment.ccv:
+                    if payment.ccv is not None:
                         ET.SubElement(creditcard, 'cardCode').text   = payment.ccv
                 elif IBank.providedBy(payment):
                     # Bank account payment type
                     bank = ET.SubElement(payment_profile, 'bankAccount')
                     
-                    if payment.account_type:
+                    if payment.account_type is not None:
                         ET.SubElement(bank, 'accountType').text = payment.account_type
                     
                     ET.SubElement(bank, 'routingNumber').text = payment.routing_number
                     ET.SubElement(bank, 'accountNumber').text = payment.account_number
                     ET.SubElement(bank, 'nameOnAccount').text = payment.name_on_account
                     
-                    if payment.echeck_type:
+                    if payment.echeck_type is not None:
                         ET.SubElement(bank, 'echeckType').text = payment.echeck_type
-                    if payment.name:
+                    if payment.name is not None:
                         ET.SubElement(bank, 'bankName').text = payment.name
                 else:
                     raise CIMException('%s is not a supported payment type' % payment.__name__)
@@ -377,11 +377,11 @@ class Serialize(object):
             if IAuthnetProfileUpdate.providedBy(trans):
                 profile = ET.SubElement(root, 'profile')
                 
-                if trans.customer_id:
+                if trans.customer_id is not None:
                     ET.SubElement(profile, 'merchantCustomerId').text = trans.customer_id
-                if trans.description:
+                if trans.description is not None:
                     ET.SubElement(profile, 'description').text = trans.description
-                if trans.email:
+                if trans.email is not None:
                     ET.SubElement(profile, 'email').text = trans.email
                 
                 ET.SubElement(profile, 'customerProfileId').text = str(trans.id)
@@ -394,7 +394,7 @@ class Serialize(object):
                 
                 ET.SubElement(payment_profile, 'customerType').text = trans.billing.entity_type
                 
-                if trans.billing:
+                if trans.billing is not None:
                     self._prototype_address(payment_profile, trans.billing, 'billTo')
                 
                 payment = trans.payment
@@ -405,27 +405,27 @@ class Serialize(object):
                     creditcard = ET.SubElement(pymnt, 'creditCard')
                     ET.SubElement(creditcard, 'cardNumber').text     = payment.number
                     ET.SubElement(creditcard, 'expirationDate').text = payment.expiration.strftime('%Y-%m')
-                    if payment.ccv:
+                    if payment.ccv is not None:
                         ET.SubElement(creditcard, 'cardCode').text   = payment.ccv
                 elif IBank.providedBy(payment):
                     # Bank account payment type
                     bank = ET.SubElement(payment_profile, 'bankAccount')
                     
-                    if payment.account_type:
+                    if payment.account_type is not None:
                         ET.SubElement(bank, 'accountType').text = payment.account_type
                     
                     ET.SubElement(bank, 'routingNumber').text = payment.routing_number
                     ET.SubElement(bank, 'accountNumber').text = payment.account_number
                     ET.SubElement(bank, 'nameOnAccount').text = payment.name_on_account
                     
-                    if payment.echeck_type:
+                    if payment.echeck_type is not None:
                         ET.SubElement(bank, 'echeckType').text = payment.echeck_type
-                    if payment.name:
+                    if payment.name is not None:
                         ET.SubElement(bank, 'bankName').text = payment.name
                 
                 ET.SubElement(payment_profile, 'customerPaymentProfileId').text = str(trans.billing_id)
                 
-                if trans.validation:
+                if trans.validation is not None:
                     ET.SubElement(root, 'validationMode').text = trans.validation
             
             # Update shipping profile
@@ -465,9 +465,9 @@ class Serialize(object):
             ET.SubElement(root, 'customerProfileId').text        = str(trans.id)
             ET.SubElement(root, 'customerPaymentProfileId').text = str(trans.billing_id)
             
-            if trans.shipping_id:
+            if trans.shipping_id is not None:
                 ET.SubElement(root, 'customerShippingAddressId').text = str(tras.shipping_id)
-            if trans.validation:
+            if trans.validation is not None:
                 ET.SubElement(root, 'validationMode').text = trans.validation
     
         return ET.tostring(root, encoding='UTF-8')
